@@ -691,7 +691,7 @@ class Dagger(Service):
         start_time = self.faust_app.loop.time()
         random: Random = Random()
         random.seed(str(key))
-        partition: int = random.randint(0, Dagger.LOCK_STRIPE_SIZE)  # nosec
+        partition: int = random.randint(0, Dagger.LOCK_STRIPE_SIZE - 1)  # nosec
         if self.asyncio_locks and self.asyncio_locks.get(partition):
             async with self.asyncio_locks.get(partition):  # type: ignore
                 value = self.workflows_weak_ref_map.get(key, None)
@@ -775,9 +775,9 @@ class Dagger(Service):
 
     async def _store_and_create_task(self, task):
         if isinstance(task, ITemplateDAGInstance):
-            await self._store_root_template_instance(task)
             if task.status.code == TaskStatusEnum.SUBMITTED.name:
                 await task.start(workflow_instance=task)
+            await self._store_root_template_instance(task)
 
     async def _process_tasks_create_event(self, stream):
         """Upon creation of tasks, store them in the datastore.
