@@ -253,7 +253,6 @@ class ITask(Record, Generic[KT, VT], serializer="raw"):  # type: ignore
             else:
                 time_completed = int(time.time())
             self.time_completed = time_completed
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         if not iterate:
             logger.debug("Skipping on_complete as iterate is false")
             return
@@ -323,15 +322,21 @@ class ExecutorTask(ITask[KT, VT], abc.ABC):
         ignore_status: bool = False,
     ) -> None:
         # pre-execute
-        if self.status.code in [
-            TaskStatusEnum.COMPLETED.name,
-            TaskStatusEnum.SKIPPED.name,
-        ]:
+        if (
+            self.status.code
+            in [
+                TaskStatusEnum.COMPLETED.name,
+                TaskStatusEnum.SKIPPED.name,
+            ]
+            and not self.reprocess_on_message
+        ):
             return await self.on_complete(
                 status=self.status, workflow_instance=workflow_instance
             )
         if (
-            ignore_status or self.status.code == TaskStatusEnum.NOT_STARTED.name
+            ignore_status
+            or self.status.code == TaskStatusEnum.NOT_STARTED.name
+            or self.reprocess_on_message
         ) and workflow_instance:
             self.status = TaskStatus(
                 code=TaskStatusEnum.EXECUTING.name, value=TaskStatusEnum.EXECUTING.value
@@ -341,7 +346,6 @@ class ExecutorTask(ITask[KT, VT], abc.ABC):
                 runtime_parameters=workflow_instance.runtime_parameters,
                 workflow_instance=workflow_instance,
             )
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         if self.status.code == TaskStatusEnum.FAILURE.name:
             await self.on_complete(
                 status=self.status, workflow_instance=workflow_instance
@@ -421,7 +425,6 @@ class IntervalTask(TriggerTask[KT, VT], abc.ABC):
                 code=TaskStatusEnum.EXECUTING.name, value=TaskStatusEnum.EXECUTING.value
             )
             self.time_submitted = int(time.time())
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         if self.time_to_execute and int(time.time()) < self.time_to_execute:
             return False
         if (
@@ -582,7 +585,6 @@ class DecisionTask(ITask[KT, VT]):
                         logger.warning(
                             f"The task instance to skip with id {next_task_id} was not found. Skipped but did not set status to {TaskStatusEnum.SKIPPED.value}"
                         )
-        await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         await self.on_complete(workflow_instance=workflow_instance)
 
     async def execute(
@@ -715,7 +717,6 @@ class SensorTask(ITask[KT, VT], abc.ABC):
                 code=TaskStatusEnum.EXECUTING.name, value=TaskStatusEnum.EXECUTING.value
             )
             self.time_submitted = int(time.time())
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
 
     async def _update_correletable_key(self, workflow_instance: ITask) -> None:
         """Updates the correletable key if the local is not the same as global key.
@@ -794,7 +795,7 @@ class KafkaAgent:
         processed_task = False
         if mappings:
             for mapping in mappings:
-                if not mapping or len(mapping) < 2:
+                if not mapping or len(mapping) < 2 or not mapping[1]:
                     logger.warning(
                         f"Listener on topic {self.__topic.get_topic_name()} has incorrect mapping {mapping}"
                     )
@@ -889,6 +890,9 @@ class KafkaAgent:
                                     await task_instance.on_complete(
                                         workflow_instance=workflow_instance
                                     )
+                                await dagger.service.services.Dagger.app._update_instance(
+                                    task=workflow_instance
+                                )  # type: ignore
                                 processed_task = True
 
                                 if getattr(self.__task, "match_only_one", False):
@@ -966,22 +970,26 @@ class INonLeafNodeTask(ITask[KT, VT], abc.ABC):
         )
 
     async def start(self, workflow_instance: Optional[ITemplateDAGInstance]) -> None:
-        if self.status.code in [
-            TaskStatusEnum.COMPLETED.name,
-            TaskStatusEnum.SKIPPED.name,
-        ]:
+        if (
+            self.status.code
+            in [
+                TaskStatusEnum.COMPLETED.name,
+                TaskStatusEnum.SKIPPED.name,
+            ]
+            and not self.reprocess_on_message
+        ):
             return await self.on_complete(
                 status=self.status, workflow_instance=workflow_instance
             )
         if (
             self.status.code == TaskStatusEnum.NOT_STARTED.name
             or self.status.code == TaskStatusEnum.SUBMITTED.name
+            or self.reprocess_on_message
         ) and workflow_instance:
             await self.execute(
                 runtime_parameters=workflow_instance.runtime_parameters,
                 workflow_instance=workflow_instance,
             )
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         logger.debug(
             f"Starting task {self.task_name} with root dag id {self.root_dag}, parent task id {self.parent_id}, and task id {self.id}"
         )
@@ -1058,7 +1066,6 @@ class ParallelCompositeTask(ITask[KT, VT], abc.ABC):
                 runtime_parameters=workflow_instance.runtime_parameters,
                 workflow_instance=workflow_instance,
             )
-            await dagger.service.services.Dagger.app._update_instance(task=workflow_instance)  # type: ignore
         logger.debug(
             f"Starting task {self.task_name} with parent task id {self.parent_id}, and task id {self.id}"
         )
@@ -1181,6 +1188,11 @@ class ITemplateDAGInstance(INonLeafNodeTask[KT, VT], abc.ABC):
         :param runtime_parameters: The runtime parameters of the task
         :param workflow_instance: The workflow object
         """
+        if self.status.code in TERMINAL_STATUSES:
+            logger.info(
+                f"Stop called in workflow in terminal state {workflow_instance.id}"
+            )
+            return
         remaining_tasks: Optional[List[ITask]] = await self.get_remaining_tasks(
             next_dag_id=self.root_dag, workflow_instance=self, tasks=[]  # type: ignore
         )  # type: ignore
